@@ -20,12 +20,12 @@
 #include "kwmapeditor.h"
 
 #include <QAction>
-#include <kactioncollection.h>
+#include <KActionCollection>
 #include <QIcon>
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 #include <QMenu>
-#include <kstandardaction.h>
-#include <kwindowsystem.h>
+#include <KStandardAction>
+#include <KWindowSystem>
 #include <QTextEdit>
 
 #include <QApplication>
